==> quarkus-logging-manager-deployment-2.1.3-sources.jar: io/quarkiverse/loggingmanager/deployment/LoggingManagerConfig$$accessor.java <==
package io.quarkiverse.loggingmanager.deployment;
public final class LoggingManagerConfig$$accessor {
    private LoggingManagerConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_basePath(Object __instance) {
        return ((LoggingManagerConfig)__instance).basePath;
    }
    @SuppressWarnings("unchecked")
    public static void set_basePath(Object __instance, Object basePath) {
        ((LoggingManagerConfig)__instance).basePath = (String)basePath;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_openapiIncluded(Object __instance) {
        return ((LoggingManagerConfig)__instance).openapiIncluded;
    }
    @SuppressWarnings("unchecked")
    public static void set_openapiIncluded(Object __instance, boolean openapiIncluded) {
        ((LoggingManagerConfig)__instance).openapiIncluded = openapiIncluded;
    }
    @SuppressWarnings("unchecked")
    public static Object get_openapiTag(Object __instance) {
        return ((LoggingManagerConfig)__instance).openapiTag;
    }
    @SuppressWarnings("unchecked")
    public static void set_openapiTag(Object __instance, Object openapiTag) {
        ((LoggingManagerConfig)__instance).openapiTag = (String)openapiTag;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_alwaysInclude(Object __instance) {
        return ((LoggingManagerConfig)__instance).alwaysInclude;
    }
    @SuppressWarnings("unchecked")
    public static void set_alwaysInclude(Object __instance, boolean alwaysInclude) {
        ((LoggingManagerConfig)__instance).alwaysInclude = alwaysInclude;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ui(Object __instance) {
        return ((LoggingManagerConfig)__instance).ui;
    }
    @SuppressWarnings("unchecked")
    public static void set_ui(Object __instance, Object ui) {
        ((LoggingManagerConfig)__instance).ui = (LoggingManagerUIConfig)ui;
    }
}

==> quarkus-logging-manager-deployment-3.0.3-sources.jar: io/quarkiverse/loggingmanager/deployment/LoggingManagerConfig$$accessor.java <==
package io.quarkiverse.loggingmanager.deployment;
@io.quarkus.Generated("Quarkus annotation processor")
public final class LoggingManagerConfig$$accessor {
    private LoggingManagerConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_basePath(Object __instance) {
        return ((LoggingManagerConfig)__instance).basePath;
    }
    @SuppressWarnings("unchecked")
    public static void set_basePath(Object __instance, Object basePath) {
        ((LoggingManagerConfig)__instance).basePath = (String)basePath;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_openapiIncluded(Object __instance) {
        return ((LoggingManagerConfig)__instance).openapiIncluded;
    }
    @SuppressWarnings("unchecked")
    public static void set_openapiIncluded(Object __instance, boolean openapiIncluded) {
        ((LoggingManagerConfig)__instance).openapiIncluded = openapiIncluded;
    }
    @SuppressWarnings("unchecked")
    public static Object get_openapiTag(Object __instance) {
        return ((LoggingManagerConfig)__instance).openapiTag;
    }
    @SuppressWarnings("unchecked")
    public static void set_openapiTag(Object __instance, Object openapiTag) {
        ((LoggingManagerConfig)__instance).openapiTag = (String)openapiTag;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_alwaysInclude(Object __instance) {
        return ((LoggingManagerConfig)__instance).alwaysInclude;
    }
    @SuppressWarnings("unchecked")
    public static void set_alwaysInclude(Object __instance, boolean alwaysInclude) {
        ((LoggingManagerConfig)__instance).alwaysInclude = alwaysInclude;
    }
}
